package com.shkj.wms.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.shkj.common.core.domain.Result;
import com.shkj.wms.domain.BusinDataTaskDetail;
import com.shkj.wms.domain.BusinDataTaskErrmsg;
import com.shkj.wms.enums.ReceivingStatusEnum;

import java.util.List;

/**
 * 设备异常记录Service接口
 * 
 * @author ruoyi
 * @date 2023-08-05
 */
public interface IBusinDataTaskErrmsgService  extends IService<BusinDataTaskErrmsg> {
    /**
     * 查询设备异常记录
     * 
     * @param id 设备异常记录主键
     * @return 设备异常记录
     */
    public BusinDataTaskErrmsg selectBusinDataTaskErrmsgById(Long id);

    /**
     * 查询设备异常记录列表
     * 
     * @param businDataTaskErrmsg 设备异常记录
     * @return 设备异常记录集合
     */
    public List<BusinDataTaskErrmsg> selectBusinDataTaskErrmsgList(BusinDataTaskErrmsg businDataTaskErrmsg);

    /**
     * 新增设备异常记录
     * 
     * @param businDataTaskErrmsg 设备异常记录
     * @return 结果
     */
    public Result<Boolean> insertBusinDataTaskErrmsg(BusinDataTaskErrmsg businDataTaskErrmsg);

    /**
     * 修改设备异常记录
     * 
     * @param businDataTaskErrmsg 设备异常记录
     * @return 结果
     */
    public  Result<Boolean> updateBusinDataTaskErrmsg(BusinDataTaskErrmsg businDataTaskErrmsg);

    /**
     * 批量删除设备异常记录
     * 
     * @param ids 需要删除的设备异常记录主键集合
     * @return 结果
     */
    public int deleteBusinDataTaskErrmsgByIds(Long[] ids);

    /**
     * 删除设备异常记录信息
     * 
     * @param id 设备异常记录主键
     * @return 结果
     */
    public  Result<Boolean> deleteBusinDataTaskErrmsgById(Long id);
}
